const googleAuth = require("../utils/googleAuth"); // Import the Google authentication verification logic
const User = require("../models/userModel"); // Import the User model

// Controller function to handle the authentication and save user info to DB
async function authenticateGoogle(req, res) {
  const { access_token } = req.body; // Accept the access token from the client
  console.log("Received access token:", access_token);

  if (!access_token) {
    return res.status(400).send("Access token is missing");
  }

  try {
    // Step 1: Verify the access token using the Google authentication logic
    const user = await googleAuth.verifyAccessToken(access_token);
    // Step 2: Retrieve additional user information (name, email, etc.) using the access token
    const userInfo = await googleAuth.getUserInfoWithAccessToken(access_token);

    // Step 3: Check if the user already exists in the database
    let existingUser = await User.findOne({ email: userInfo.email });

    if (existingUser) {
      // User already exists, update their information
      existingUser.firstName = userInfo.given_name;
      existingUser.lastName = userInfo.family_name;
      existingUser.photo = userInfo.picture;
      existingUser.emailVerified = userInfo.email_verified;
      existingUser.active = true; // Mark the user as active

      // Optionally, you could update other fields like bio, location, etc.

      await existingUser.save(); // Save updated user info to the database
      return res.json({
        status: true,
        token: access_token,
        message: "User info updated successfully",
        user: existingUser, // Send the updated user data
      });
    } else {
      // Step 4: If the user doesn't exist, create a new user
      const newUser = new User({
        firstName: userInfo.given_name,
        lastName: userInfo.family_name,
        email: userInfo.email,
        photo: userInfo.picture,
        emailVerified: userInfo.email_verified,
        role: "user", // Default to "user"
        active: true, // Mark the user as active
        // Optionally, set more fields like bio, location, etc.
      });

      await newUser.save(); // Save the new user to the database
      return res.json({
        status: true,
        token: access_token,
        message: "User created successfully",
        user: newUser, // Send the created user data
      });
    }
  } catch (error) {
    console.error("Error verifying token:", error);
    return res.status(400).send("Error verifying token: " + error.message);
  }
}

module.exports = {
  authenticateGoogle,
};
