const linkedinAuth = require("../utils/linkedinAuth"); // Import LinkedIn authentication helper
const User = require("../models/userModel"); // Import User model

// Handle LinkedIn authentication
async function authenticateLinkedIn(req, res) {
  const { access_token } = req.body; // Get access token from request
  console.log(access_token);

  if (!access_token) {
    return res.status(400).send("Access token is missing");
  }

  try {
    // Step 1: Verify access token and retrieve LinkedIn user details
    const user = await linkedinAuth.verifyAccessToken(access_token);

    // Step 2: Get the user's email address from LinkedIn
    const email = await linkedinAuth.getUserEmail(access_token);

    // Step 3: Check if the user already exists in the database
    let existingUser = await User.findOne({ email });

    if (existingUser) {
      // Update user information
      existingUser.firstName = user.first_name;
      existingUser.lastName = user.last_name;
      existingUser.profileUrl = user.profile_url;
      existingUser.headline = user.headline;
      existingUser.active = true;

      await existingUser.save(); // Save updated user information to the database

      return res.json({
        status: true,
        message: "User info updated successfully",
        user: existingUser,
      });
    } else {
      // Create a new user if not found
      const newUser = new User({
        firstName: user.first_name,
        lastName: user.last_name,
        email,
        profileUrl: user.profile_url,
        headline: user.headline,
        role: "user", // Default role
        active: true,
      });

      await newUser.save(); // Save the new user to the database

      return res.json({
        status: true,
        message: "User created successfully",
        user: newUser,
      });
    }
  } catch (error) {
    console.error("Error authenticating with LinkedIn:", error);
    return res
      .status(400)
      .send("Error authenticating with LinkedIn: " + error.message);
  }
}

module.exports = {
  authenticateLinkedIn,
};
