const Notification = require("../models/notificationModel");

const createAndEmitNotification = async (io, userId, message, type, link) => {
  try {
    // Create a new notification for the user
    const newNotification = new Notification({
      user: userId, // User who will receive the notification
      message: message,
      type: type, // Ensure this is one of the valid types (connection, like, comment, message, or other)
      link: link,
    });

    // Save the notification to the database
    await newNotification.save();

    // Emit the notification to the user's socket for real-time updates
    io.to(userId.toString()).emit("New Notification", {
      message: newNotification.message,
      createdAt: newNotification.createdAt,
      link: newNotification.link,
    });
  } catch (error) {
    console.error("Error creating and emitting notification:", error);
  }
};

module.exports = { createAndEmitNotification };
