const nodemailer = require("nodemailer");
const htmlToText = require("html-to-text");

module.exports = class Email {
  constructor(user, url) {
    this.to = user.email;
    this.firstName = user.name.split(" ")[0];
    this.url = url;
    this.from = `Your Name <${process.env.EMAIL_FROM}>`; // Set the sender's email address
  }

  newTransport() {
    if (process.env.NODE_ENV === "production") {
      // For production, use Gmail's SMTP settings
      return nodemailer.createTransport({
        service: "gmail", // Use Gmail's SMTP service
        auth: {
          user: process.env.EMAIL_USERNAME, // Gmail username (your email)
          pass: process.env.EMAIL_PASSWORD, // Gmail password or App-specific password
        },
      });
    }

    return nodemailer.createTransport({
      host: process.env.EMAIL_HOST,
      port: process.env.EMAIL_PORT,
      auth: {
        user: process.env.EMAIL_USERNAME,
        pass: process.env.EMAIL_PASSWORD,
      },
    });
  }

  // Send the actual email
  async send(subject, htmlContent) {
    // 1) Define email options
    const mailOptions = {
      from: this.from,
      to: this.to,
      subject,
      html: htmlContent,
      text: htmlToText.fromString(htmlContent), // Convert HTML to plain text for email clients that don't support HTML
    };

    // 2) Send the email using the transporter
    await this.newTransport().sendMail(mailOptions);
  }

  async sendWelcome() {
    const htmlContent = `
      <h1>Welcome, ${this.firstName}!</h1>
      <p>Welcome to our service. We're glad to have you with us.</p>
      <p><a href="${this.url}">Click here to get started.</a></p>
    `;
    await this.send("Welcome to the Service!", htmlContent);
  }
};
